@@ -371,11 +371,17 @@ class TestApp(GoodAppTestCase):
             '--page-requisites',
             '--reject-regex', '/post/',
         ])
+        builder = Builder(args)
+
         with cd_tempdir():
-            engine = Builder(args).build()
+            engine = builder.build()
             exit_code = yield engine()
+
         self.assertEqual(42, exit_code)
 
+        engine = builder.factory['Engine']
+        self.assertEqual(2, engine.concurrent)
+
     @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
     def test_app_python_script_stop(self):
         arg_parser = AppArgumentParser()
@@ -404,11 +410,17 @@ class TestApp(GoodAppTestCase):
             '--page-requisites',
             '--reject-regex', '/post/',
         ])
+        builder = Builder(args)
+
         with cd_tempdir():
-            engine = Builder(args).build()
+            engine = builder.build()
             exit_code = yield engine()
+
         self.assertEqual(42, exit_code)
 
+        engine = builder.factory['Engine']
+        self.assertEqual(2, engine.concurrent)
+
     @tornado.testing.gen_test(timeout=DEFAULT_TIMEOUT)
     def test_iri_handling(self):
         arg_parser = AppArgumentParser()
@@ -692,7 +704,7 @@ class TestApp(GoodAppTestCase):
             '--no-robots',
             '--phantomjs',
             '--phantomjs-wait', '0.1',
-            '--phantomjs-scroll', '10',
+            '--phantomjs-scroll', '20',
         ])
         builder = Builder(args)
         with cd_tempdir():
