@@ -17,13 +17,14 @@ from wpull.database import Status
 from wpull.document import HTMLReader
 from wpull.errors import (ProtocolError, ServerError, ConnectionRefused,
     DNSNotFound, NetworkError)
-from wpull.http.request import Response, Request
+from wpull.http.request import Response
 from wpull.http.web import RichClientResponseType
 from wpull.item import LinkType
 from wpull.namevalue import NameValueRecord
 from wpull.scraper import HTMLScraper, DemuxDocumentScraper, CSSScraper
 from wpull.stats import Statistics
-from wpull.url import URLInfo, DemuxURLFilter, SpanHostsFilter
+from wpull.url import URLInfo
+from wpull.urlfilter import DemuxURLFilter, SpanHostsFilter
 import wpull.util
 from wpull.waiter import LinearWaiter
 from wpull.warc import WARCRecord
@@ -100,7 +101,7 @@ WebProcessorInstances = namedlist.namedtuple(
 '''WebProcessorInstances
 
 Args:
-    url_filter ( :class:`.url.DemuxURLFilter`): The URL filter.
+    url_filter ( :class:`.urlfilter.DemuxURLFilter`): The URL filter.
     document_scraper (:class:`.scaper.DemuxDocumentScraper`): The document
         scraper.
     file_writer (:class`.writer.BaseWriter`): The file writer.
@@ -685,8 +686,8 @@ class WebProcessorSession(object):
 
 class PhantomJSController(object):
     '''PhantomJS Page Controller.'''
-    def __init__(self, client, wait_time=1, num_scrolls=5, snapshot=True,
-    warc_recorder=None, viewport_size=(1024, 3072), paper_size=(2048, 6144),
+    def __init__(self, client, wait_time=1.0, num_scrolls=10, snapshot=True,
+    warc_recorder=None, viewport_size=(1200, 1920), paper_size=(2400, 3840),
     smart_scroll=True):
         self.client = client
         self._wait_time = wait_time
@@ -733,21 +734,27 @@ class PhantomJSController(object):
             _logger.debug('Scrolling page. Count={0}.'.format(scroll_count))
 
             pre_scroll_counter_values = remote.resource_counter.values()
+
             scroll_position = yield remote.eval('page.scrollPosition')
             scroll_position['top'] += self._viewport_size[1]
 
-            self._log_action('set_scroll_top', scroll_position['top'])
-            yield remote.set('page.scrollPosition', scroll_position)
-            yield remote.call('page.sendEvent', 'keypress', 'PageDown')
-            yield remote.call('page.sendEvent', 'keydown', 'PageDown')
-            yield remote.call('page.sendEvent', 'keyup', 'PageDown')
+            yield self.scroll_to(remote, 0, scroll_position['top'])
 
             total_scroll_count += 1
 
             self._log_action('wait', self._wait_time)
             yield wpull.util.sleep(self._wait_time)
 
-            if remote.resource_counter.values() == pre_scroll_counter_values \
+            post_scroll_counter_values = remote.resource_counter.values()
+
+            _logger.debug(
+                'Counter values pre={0} post={1}'.format(
+                    pre_scroll_counter_values,
+                    post_scroll_counter_values
+                )
+            )
+
+            if post_scroll_counter_values == pre_scroll_counter_values \
             and self._smart_scroll:
                 break
 
@@ -758,6 +765,8 @@ class PhantomJSController(object):
             else:
                 break
 
+        yield self.scroll_to(remote, 0, 0)
+
         _logger.info(
             gettext.ngettext(
                 'Scrolled page {num} time.',
@@ -769,9 +778,30 @@ class PhantomJSController(object):
         if self._warc_recorder:
             self._add_warc_action_log(url)
 
+    @tornado.gen.coroutine
+    def scroll_to(self, remote, x, y):
+        page_down_key = yield remote.eval('page.event.key.PageDown')
+
+        self._log_action('set_scroll_left', x)
+        self._log_action('set_scroll_top', y)
+
+        yield remote.set('page.scrollPosition', {'left': x, 'top': y})
+        yield remote.set('page.evaluate',
+            '''
+            function() {{
+                if (window) {{
+                    window.scrollTo({0}, {1});
+                }}
+            }}
+            '''.format(x, y)
+        )
+        yield remote.call('page.sendEvent', 'keypress', page_down_key)
+        yield remote.call('page.sendEvent', 'keydown', page_down_key)
+        yield remote.call('page.sendEvent', 'keyup', page_down_key)
+
     @tornado.gen.coroutine
     def snapshot(self, remote, html_path=None, render_path=None):
-        '''Take snapshot.'''
+        '''Take HTML and PDF snapshot.'''
         content = yield remote.eval('page.content')
         url = yield remote.eval('page.url')
 
@@ -798,6 +828,7 @@ class PhantomJSController(object):
         raise tornado.gen.Return(content)
 
     def _add_warc_snapshot(self, filename, content_type, url):
+        '''Add the snaphot to the WARC file.'''
         _logger.debug('Adding snapshot record.')
 
         record = WARCRecord()
@@ -816,6 +847,7 @@ class PhantomJSController(object):
             self._warc_recorder.write_record(record)
 
     def _log_action(self, name, value):
+        '''Add a action to the action log.'''
         _logger.debug('Action: {0} {1}'.format(name, value))
 
         self._actions.append({
@@ -825,6 +857,7 @@ class PhantomJSController(object):
         })
 
     def _add_warc_action_log(self, url):
+        '''Add the acton log to the WARC file.'''
         _logger.debug('Adding action log record.')
 
         log_data = json.dumps(
